==> gnue-forms_0.5.4.orig.tar.gz: gnue-forms-0.5.4/src/uidrivers/wx/widgets/page.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
# FILE:
# UIwxpython.py
#
# DESCRIPTION:
# A wxPython based user interface driver for GNUe forms.
#
# NOTES:
#
from wxPython.wx import *


## from gnue.forms.GFForm import *
## from gnue.forms.uidrivers._base.UIdriver import *

## from gnue.forms.uidrivers.wx.GFwxApp import *
## from gnue.forms.uidrivers.wx.common import *
from gnue.forms.uidrivers.wx.common import _setDefaultEventHandlers

## #from gnue.forms.uidrivers.wx.UIWXSplashScreen import *
from gnue.forms.uidrivers.wx.widgets._base import UIHelper
#from gnue.common import *

#
# UIPage
#
# Widget set specific function that creates a single instance of a page
#
# Note: The event trap for changing notebook pages is attached to the UIForm
#
class UIPage(UIHelper):
  def _createWidget(self, event, spacer):

    object = event.object

    newWidget = self._uiForm._wrapper.createPage(object)
    _setDefaultEventHandlers(newWidget, event.eventHandler, event.initialize, self._uiDriver)
    self._containerToolkitWidget = newWidget
    return newWidget

configuration = {
    'baseClass'  : UIPage,
    'provides'   : 'GFPage',
    'container'  : 1,
    }

==> gnue-forms_0.5.11.orig.tar.gz: gnue-forms-0.5.11/src/uidrivers/wx/widgets/page.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
# DESCRIPTION:
# A wxPython based user interface driver for GNUe forms.
#
# NOTES:
#
# $Id: page.py 6851 2005-01-03 20:59:28Z jcater $

from wxPython.wx import *

from gnue.forms.uidrivers.wx.common import _setDefaultEventHandlers
from gnue.forms.uidrivers.wx.widgets._base import UIHelper

# =============================================================================
# Wrap an UI layer around a page widget
# Note: The event trap for changing notebook pages is attached to the UIForm
# =============================================================================
class UIPage(UIHelper):
  """
  Creates a single instance of a page.
  """

  # --------------------------------------------------------------------------
  # Create a page widget
  # --------------------------------------------------------------------------
  def _createWidget(self, event, spacer):
    """
    Creates a new Page widget.
    """
    object = event.object

    newWidget = self._uiForm._wrapper.createPage(object)
    _setDefaultEventHandlers(newWidget, event.eventHandler, event.initialize, self._uiDriver)
    self._containerToolkitWidget = newWidget
    return newWidget


# ----------------------------------------------------------------------------
# Configuration data
# ----------------------------------------------------------------------------
configuration = {
    'baseClass'  : UIPage,
    'provides'   : 'GFPage',
    'container'  : 1,
    }
